@@ -1,9 +1,8 @@
-from typing import Optional, Callable, Any, Tuple, TypeVar
+from typing import Any, Callable, Optional, Tuple, TypeVar
 
 from ..model import Model
 from ..util import use_nvtx_range
 
-
 _ModelT = TypeVar("_ModelT", bound=Model)
 
 
